@@ -5,7 +5,11 @@
 #include <QByteArray>
 #include <QString>
 
+struct wl_registry;
+
 QT_BEGIN_NAMESPACE
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
 
 #if !defined(Q_WAYLAND_CLIENT_HARDWARE_INTEGRATION_EXPORT)
 #  if defined(QT_SHARED)
@@ -30,6 +34,7 @@ namespace QtWayland {
 
         struct ::qt_hardware_integration *object() { return m_qt_hardware_integration; }
         const struct ::qt_hardware_integration *object() const { return m_qt_hardware_integration; }
+        static qt_hardware_integration *fromObject(struct ::qt_hardware_integration *object);
 
         bool isInitialized() const;
 
@@ -54,6 +59,7 @@ namespace QtWayland {
     };
 }
 
+QT_WARNING_POP
 QT_END_NAMESPACE
 
 #endif
