@@ -1,7 +1,7 @@
 #ifndef QT_WAYLAND_SERVER_TOUCH_EXTENSION
 #define QT_WAYLAND_SERVER_TOUCH_EXTENSION
 
-#include "wayland-server.h"
+#include "wayland-server-core.h"
 #include <QtWaylandCompositor/private/wayland-touch-extension-server-protocol.h>
 #include <QByteArray>
 #include <QMultiMap>
@@ -45,6 +45,7 @@ namespace QtWaylandServer {
             virtual ~Resource() {}
 
             qt_touch_extension *touch_extension_object;
+            qt_touch_extension *object() { return touch_extension_object; } 
             struct ::wl_resource *handle;
 
             struct ::wl_client *client() const { return wl_resource_get_client(handle); }
@@ -76,7 +77,7 @@ namespace QtWaylandServer {
 
 
         enum flags {
-            flags_mouse_from_touch = 0x1
+            flags_mouse_from_touch = 0x1,
         };
 
         void send_touch(uint32_t time, uint32_t id, uint32_t state, int32_t x, int32_t y, int32_t normalized_x, int32_t normalized_y, int32_t width, int32_t height, uint32_t pressure, int32_t velocity_x, int32_t velocity_y, uint32_t flags, const QByteArray &rawdata);
